'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames2 = require('classnames');

var _classnames3 = _interopRequireDefault(_classnames2);

var _immutable = require('immutable');

var _yylibUi = require('yylib-ui');

var _ajax = require('yylib-utils/ajax');

var _ajax2 = _interopRequireDefault(_ajax);

var _jsCookie = require('js-cookie');

var _jsCookie2 = _interopRequireDefault(_jsCookie);

var _SearchCondition = require('./SearchCondition');

var _SearchCondition2 = _interopRequireDefault(_SearchCondition);

var _SearchScheme = require('./SearchScheme');

var _SearchScheme2 = _interopRequireDefault(_SearchScheme);

var _SearchTable = require('./SearchTable');

var _SearchTable2 = _interopRequireDefault(_SearchTable);

var _Url = require('./Url');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var field = _yylibUi.YYClass.field,
    PropTypes = _yylibUi.YYClass.PropTypes;
var Header = _yylibUi.YYLayout.Header,
    Sider = _yylibUi.YYLayout.Sider,
    Content = _yylibUi.YYLayout.Content,
    Footer = _yylibUi.YYLayout.Footer;


var FormItemType = require('../../../widgets/FormItemType');

function noop() {}

var uiMeta = {
    name: 'ijz-search',
    fields: [
    //field 参数列表：字段属性名|属性默认值|属性类型|是否必填|属性描述
    field('prefixCls', 'ijz-search', PropTypes.string, false, '样式名前缀'), field('className', '', PropTypes.string, false, '样式'), field('visible', true, PropTypes.bool, false, '组件是否显示'), field('onSearchClick', noop, PropTypes.func, false, '查询回调')]
};

var IjzSearch = _yylibUi.YYClass.create({
    uiMeta: uiMeta,

    displayName: 'IjzSearch',

    getInitialState: function getInitialState() {
        return {
            _dataSource: [],
            _dataItem: [],
            _visible: false,
            _schemeId: null,
            _schemeName: null,
            _schemeList: []
        };
    },
    componentWillMount: function componentWillMount() {
        var findUI = this.context.findUI;

        this.procDataItem();
        this.procSchemeQuery();
    },
    componentWillReceiveProps: function componentWillReceiveProps(nextProps) {
        if (!(0, _immutable.is)((0, _immutable.fromJS)(this.props.children), (0, _immutable.fromJS)(nextProps.children))) {
            this.procDataItem(nextProps.children);
        }
    },
    getClassName: function getClassName() {
        var prefixCls = this.props.prefixCls;

        return (0, _classnames3.default)(prefixCls);
    },
    procDataItem: function procDataItem(value) {
        var children = this.props.children;

        var _dataItem = [],
            _dataSource = [];
        _react2.default.Children.map(value || children, function (item) {
            if (_react2.default.isValidElement(item)) {
                var inputprops = item.props.inputprops ? _lodash2.default.clone(item.props.inputprops) : {};
                // 下拉选择特殊处理
                if (inputprops && item.props.inputtype === FormItemType.select) {
                    var items = item.props.children ? _lodash2.default.clone(item.props.children) : [];
                    var options = [];
                    if (items && items.length > 0) {
                        _lodash2.default.forEach(items, function (item) {
                            var option = {};
                            option.value = item.value;
                            option.text = item.text || item.children;
                            options.push(option);
                        });
                    }
                    inputprops.items = options;
                }
                _dataItem.push({
                    key: item.props.uikey,
                    fieldkey: item.props.fieldkey || item.props.uikey,
                    title: item.props.title,
                    fieldtype: item.props.fieldtype,
                    inputtype: item.props.inputtype,
                    inputprops: inputprops,
                    oper: item.props.oper || [],
                    enableOrder: item.props.enableOrder === undefined ? false : item.props.enableOrder,
                    enableSearch: item.props.enableSearch === undefined ? true : item.props.enableSearch,
                    hidden: item.props.hidden === undefined ? false : item.props.hidden,
                    required: item.props.required === undefined ? false : item.props.required,
                    readonly: item.props.readonly === undefined ? false : item.props.readonly,
                    presetFunc: item.props.funcId ? {
                        funcId: item.props.funcId,
                        funcCode: item.props.funcCode,
                        funcName: item.props.funcName
                    } : null
                });
                if (item.props.required && _lodash2.default.findIndex(_dataSource, { key: item.props.uikey }) === -1) {
                    _dataSource.push(_extends({}, _dataItem[_dataItem.length - 1], {
                        logic: _dataItem[_dataItem.length - 1]['oper'][0],
                        id: item.props.uikey + '_' + Date.now()
                    }));
                }
            }
        });
        this.setState({ _dataItem: _dataItem, _dataSource: _dataSource });
    },
    procSchemeQuery: function procSchemeQuery() {
        var _this = this;

        var areaid = this.props.areaid;

        var REF_BASE_URL = window.EnvConfig.REF_BASE_URL;
        if (!!!areaid) return;
        _ajax2.default.postJSONWithCookies(REF_BASE_URL + _Url.SchemeQuery, {
            "busiParamJson": JSON.stringify({ areaid: areaid }),
            "sysParamJson": { pagecs: _jsCookie2.default.get("cookiets") }
        }, function (result) {
            if (result.success === true) {
                _this.setState({ _schemeList: result.data });
            }
        });
    },
    procSchemeAdd: function procSchemeAdd() {
        var _this2 = this;

        var _props = this.props,
            areaid = _props.areaid,
            uiRunMode = _props.uiRunMode;
        var _state = this.state,
            _dataSource = _state._dataSource,
            _schemeName = _state._schemeName;

        var REF_BASE_URL = window.EnvConfig.REF_BASE_URL;
        var otherProps = { name: _schemeName, isdevelop: false, isquickqs: false };
        if (uiRunMode === 'design') {
            otherProps['isdevelop'] = true;
        }
        _ajax2.default.postJSONWithCookies(REF_BASE_URL + _Url.SchemeAdd, {
            "busiParamJson": JSON.stringify(_extends({}, otherProps, { areaid: areaid, renderobj4web: _dataSource })),
            "sysParamJson": { pagecs: _jsCookie2.default.get("cookiets") }
        }, function (result) {
            _this2.procSchemeQuery();
        });
    },
    procSchemeUpdate: function procSchemeUpdate() {
        var _this3 = this;

        var _props2 = this.props,
            areaid = _props2.areaid,
            uiRunMode = _props2.uiRunMode;
        var _state2 = this.state,
            _dataSource = _state2._dataSource,
            _schemeId = _state2._schemeId,
            _schemeName = _state2._schemeName;

        var REF_BASE_URL = window.EnvConfig.REF_BASE_URL;
        var otherProps = { isdevelop: false, isquickqs: false };
        if (uiRunMode === 'design') {
            otherProps['isdevelop'] = true;
        }
        _ajax2.default.postJSONWithCookies(REF_BASE_URL + _Url.SchemeUpdate, {
            "busiParamJson": JSON.stringify(_extends({}, otherProps, {
                areaid: areaid,
                name: _schemeName,
                pk_ncc_queryscheme: _schemeId,
                renderobj4web: _dataSource
            })),
            "sysParamJson": { pagecs: _jsCookie2.default.get("cookiets") }
        }, function (result) {
            _this3.procSchemeQuery();
        });
    },
    procSchemeDel: function procSchemeDel(schemeId) {
        var _this4 = this;

        var REF_BASE_URL = window.EnvConfig.REF_BASE_URL;
        var otherProps = { isdevelop: false, isquickqs: false };
        if (uiRunMode === 'design') {
            otherProps['isdevelop'] = true;
        }
        _ajax2.default.postJSONWithCookies(REF_BASE_URL + _Url.SchemeDelete, {
            "busiParamJson": JSON.stringify(_extends({}, otherProps, {
                pk_ncc_queryscheme: schemeId
            })),
            "sysParamJson": { pagecs: _jsCookie2.default.get("cookiets") }
        }, function (result) {
            _this4.procSchemeQuery();
        });
    },
    handleConditionClick: function handleConditionClick(key) {
        var _state3 = this.state,
            _dataItem = _state3._dataItem,
            _dataSource = _state3._dataSource;

        var cond = _lodash2.default.find(_dataItem, { key: key });
        if (_lodash2.default.findIndex(_dataSource, { key: key }) === -1) {
            _dataSource.push(_extends({}, cond, { logic: cond['oper'][0], id: cond.key + '_' + Date.now() }));
            this.setState({ _dataSource: _dataSource });
        }
    },
    handleSchemeClick: function handleSchemeClick(key) {
        var _schemeList = this.state._schemeList;

        var scheme = _lodash2.default.find(_schemeList, { pk_ncc_queryscheme: key });
        this.setState({ _dataSource: scheme.renderobj4web, _schemeId: key, _schemeName: scheme.name });
    },
    handleSchemeDelClick: function handleSchemeDelClick(key) {
        this.procSchemeDel(key);
    },
    handleSearchClick: function handleSearchClick() {
        var onSearchClick = this.props.onSearchClick;
        var _dataSource = this.state._dataSource;

        var cb = _dataSource.map(function (_ref) {
            var key = _ref.key,
                logic = _ref.logic,
                value = _ref.value,
                inputtype = _ref.inputtype;

            return { key: key, logic: logic, value: value, inputtype: inputtype };
        });
        if (this.ref.validate() === true) {
            onSearchClick(cb);
        }
    },
    handleClearClick: function handleClearClick() {
        var dataSource = [];
        this.state._dataSource.map(function (item) {
            delete item.value;
            dataSource.push(item);
        });
        this.setState({ _dataSource: dataSource });
    },
    handleSaveScheme: function handleSaveScheme() {
        this.setState({ _visible: true });
    },
    handleUpdateScheme: function handleUpdateScheme() {
        this.procSchemeUpdate();
    },
    handleModalOk: function handleModalOk() {
        this.setState({ _visible: false });
        this.procSchemeAdd();
    },
    handleModalCancel: function handleModalCancel() {
        this.setState({ _visible: false });
    },
    render: function render() {
        var _this5 = this;

        var _props3 = this.props,
            className = _props3.className,
            visible = _props3.visible,
            otherProps = _objectWithoutProperties(_props3, ['className', 'visible']);

        var _state4 = this.state,
            _dataItem = _state4._dataItem,
            _dataSource = _state4._dataSource,
            _schemeList = _state4._schemeList;


        var visibleClass = (0, _classnames3.default)(_defineProperty({}, this.getClassName() + '-hide', !visible));

        return _react2.default.createElement(
            _yylibUi.YYLayout,
            { className: (0, _classnames3.default)(this.getClassName(), visibleClass, className) },
            _react2.default.createElement(
                _yylibUi.YYLayout,
                null,
                _react2.default.createElement(
                    Sider,
                    null,
                    _react2.default.createElement(
                        _yylibUi.YYTabs,
                        { defaultActiveKey: '1' },
                        _react2.default.createElement(
                            _yylibUi.YYTab,
                            { tab: '\u5019\u9009\u6761\u4EF6', key: '1' },
                            _react2.default.createElement(_SearchCondition2.default, { dataItem: _dataItem, onConditionClick: this.handleConditionClick })
                        ),
                        _react2.default.createElement(
                            _yylibUi.YYTab,
                            { tab: '\u67E5\u8BE2\u65B9\u6848', key: '2' },
                            _react2.default.createElement(_SearchScheme2.default, { dataItem: _schemeList,
                                onSchemeClick: this.handleSchemeClick,
                                onSchemeDelClick: this.handleSchemeDelClick
                            })
                        )
                    )
                ),
                _react2.default.createElement(
                    Content,
                    null,
                    _react2.default.createElement(
                        _yylibUi.YYTabs,
                        { defaultActiveKey: '1', type: 'card' },
                        _react2.default.createElement(
                            _yylibUi.YYTab,
                            { tab: '\u67E5\u8BE2\u6761\u4EF6', key: '1' },
                            _react2.default.createElement(_SearchTable2.default, { ref: function ref(t) {
                                    return _this5.ref = t;
                                }, dataSource: _dataSource })
                        )
                    )
                )
            ),
            _react2.default.createElement(
                Footer,
                null,
                _react2.default.createElement(
                    _yylibUi.YYButton,
                    { type: 'success', onClick: this.handleUpdateScheme },
                    '\u4FDD\u5B58\u65B9\u6848'
                ),
                _react2.default.createElement(
                    _yylibUi.YYButton,
                    { type: 'error', onClick: this.handleSaveScheme },
                    '\u53E6\u5B58\u65B0\u65B9\u6848'
                ),
                _react2.default.createElement(
                    _yylibUi.YYButton,
                    { type: 'primary', onClick: this.handleSearchClick },
                    '\u67E5\u8BE2'
                ),
                _react2.default.createElement(
                    _yylibUi.YYButton,
                    { onClick: this.handleClearClick },
                    '\u6E05\u7A7A\u503C'
                )
            ),
            _react2.default.createElement(
                _yylibUi.YYModal,
                { title: '\u53E6\u5B58\u65B0\u65B9\u6848', visible: this.state._visible,
                    className: (0, _classnames3.default)(this.getClassName() + '-modal'),
                    onOk: this.handleModalOk, onCancel: this.handleModalCancel },
                _react2.default.createElement(
                    'span',
                    null,
                    '\u65B9\u6848\u540D\u79F0\uFF1A'
                ),
                _react2.default.createElement(_yylibUi.YYInput, { placeholder: '\u597D\u8BB0\u7684\u65B9\u6848\u540D\u79F0', onChange: function onChange(e) {
                        _this5.setState({ _schemeName: e.currentTarget.value });
                    } })
            )
        );
    }
});

module.exports = IjzSearch;